==> kubernetes-model-0.1.5-sources.jar: annotations/io/fabric8/kubernetes/api/model/GCEPersistentDiskVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class GCEPersistentDiskVolumeSourceFluent<T extends GCEPersistentDiskVolumeSourceFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String fsType;     Integer partition;     String pdName;     Boolean readOnly;     Map<String, Object> additionalProperties = new HashMap();

    public String getFsType(){
    return this.fsType;
    }
    public T withFsType( String fsType){
    this.fsType=fsType; return (T) this;
    }
    public Integer getPartition(){
    return this.partition;
    }
    public T withPartition( Integer partition){
    this.partition=partition; return (T) this;
    }
    public String getPdName(){
    return this.pdName;
    }
    public T withPdName( String pdName){
    this.pdName=pdName; return (T) this;
    }
    public Boolean isReadOnly(){
    return this.readOnly;
    }
    public T withReadOnly( Boolean readOnly){
    this.readOnly=readOnly; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }



}

==> kubernetes-model-1.0.13-sources.jar: annotations/io/fabric8/kubernetes/api/model/GCEPersistentDiskVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class GCEPersistentDiskVolumeSourceFluent<T extends GCEPersistentDiskVolumeSourceFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String fsType;     Integer partition;     String pdName;     Boolean readOnly;     Map<String, Object> additionalProperties = new HashMap();

    public String getFsType(){
    return this.fsType;
    }
    public T withFsType( String fsType){
    this.fsType=fsType; return (T) this;
    }
    public Integer getPartition(){
    return this.partition;
    }
    public T withPartition( Integer partition){
    this.partition=partition; return (T) this;
    }
    public String getPdName(){
    return this.pdName;
    }
    public T withPdName( String pdName){
    this.pdName=pdName; return (T) this;
    }
    public Boolean isReadOnly(){
    return this.readOnly;
    }
    public T withReadOnly( Boolean readOnly){
    this.readOnly=readOnly; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
GCEPersistentDiskVolumeSourceFluent that = (GCEPersistentDiskVolumeSourceFluent) o;
if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
if (partition != null ? !partition.equals(that.partition) :that.partition != null) return false;
if (pdName != null ? !pdName.equals(that.pdName) :that.pdName != null) return false;
if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
